import { TimeAxisLabelFormatCollection } from "./igr-time-axis-label-format-collection";
import { IgrCategoryXAxis, IIgrCategoryXAxisProps } from "./igr-category-x-axis";
import { OrdinalTimeXAxis } from "./OrdinalTimeXAxis";
/**
 * A horizontal axis that uses an ordinal DateTime scale.
 * On an ordinal time axis, datapoints are aligned according to their order in the ItemsSource, like a category axis.
*
* You can use the `IgxOrdinalTimeXAxisComponent` to display dates at equidistant.
*
* ```html
* <igx-data-chart
*     [dataSource]="data">
*     <igx-ordinal-time-x-axis
* 		dateTimeMemberPath="date"
* 		#xAxis>
*     </igx-ordinal-time-x-axis>
* </igx-data-chart>
* ```
*/
export declare class IgrOrdinalTimeXAxis<P extends IIgrOrdinalTimeXAxisProps = IIgrOrdinalTimeXAxisProps> extends IgrCategoryXAxis<P> {
    protected createImplementation(): OrdinalTimeXAxis;
    readonly i: OrdinalTimeXAxis;
    constructor(props: P);
    /**
     * Gets or sets the DateTime mapping property for the axis.
    */
    dateTimeMemberPath: string;
    private _labelFormats;
    /**
     * A list of axis label formats to apply, which are selected according to the visible axis range.
     * The label format selected will be the one with the largest range smaller than the visible range of the axis.
    *
    * You can use the `labelFormats` for adjusting the labels depending on the range of the time shown by the chart.
    *
    * ```html
    * <igx-data-chart
    *     [dataSource]="data">
    * 	<igx-ordinal-time-x-axis
    * 		[labelFormats]="labelFormats"
    * 		dateTimeMemberPath="time"
    * 		#xAxis>
    *     </igx-ordinal-time-x-axis>
    * </igx-data-chart>
    * ```
    */
    labelFormats: TimeAxisLabelFormatCollection;
    minimumValue: Date;
    maximumValue: Date;
}
export interface IIgrOrdinalTimeXAxisProps extends IIgrCategoryXAxisProps {
    /**
     * Gets or sets the DateTime mapping property for the axis.
    */
    dateTimeMemberPath?: string;
    minimumValue?: Date;
    maximumValue?: Date;
}
