import * as tslib_1 from "tslib";
import { delegateCombine, delegateRemove } from "igniteui-react-core/ES5/type";
import { CalloutCollisionMode_$type } from "./CalloutCollisionMode";
import { CalloutContentUpdatingEventArgs } from "./igr-callout-content-updating-event-args";
import { CalloutLabelUpdatingEventArgs } from "./igr-callout-label-updating-event-args";
import { CalloutSeriesSelectingEventArgs } from "./igr-callout-series-selecting-event-args";
import { IgrAnnotationLayer } from "./igr-annotation-layer";
import { CalloutLayer } from "./CalloutLayer";
import { ensureBool, brushToString, stringToBrush, ensureEnum } from "igniteui-react-core/ES5/componentUtil";
/**
 * Represents an annotation layer that displays crosshair lines that cross through the closest value of the target series under the cursor.
*/
var IgrCalloutLayer = /** @class */ (function (_super) {
    tslib_1.__extends(IgrCalloutLayer, _super);
    function IgrCalloutLayer(props) {
        var _this = _super.call(this, props) || this;
        _this._calloutContentUpdating = null;
        _this._calloutContentUpdating_wrapped = null;
        _this._calloutLabelUpdating = null;
        _this._calloutLabelUpdating_wrapped = null;
        _this._calloutSeriesSelecting = null;
        _this._calloutSeriesSelecting_wrapped = null;
        return _this;
    }
    IgrCalloutLayer.prototype.createImplementation = function () {
        return new CalloutLayer();
    };
    Object.defineProperty(IgrCalloutLayer.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "labelMemberPath", {
        /**
         * Gets or sets the label mapping property for the callouts.
        */
        get: function () {
            return this.i.oq;
        },
        set: function (v) {
            this.i.oq = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "xMemberPath", {
        /**
         * Gets or sets the label mapping property for the callouts.
        */
        get: function () {
            return this.i.ow;
        },
        set: function (v) {
            this.i.ow = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "yMemberPath", {
        /**
         * Gets or sets the label mapping property for the callouts.
        */
        get: function () {
            return this.i.oz;
        },
        set: function (v) {
            this.i.oz = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "keyMemberPath", {
        /**
         * Gets or sets the key mapping property for the callouts.
        */
        get: function () {
            return this.i.on;
        },
        set: function (v) {
            this.i.on = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "isCalloutOffsettingEnabled", {
        /**
         * Gets or sets whether to allow the callouts to be variable distances from the target points, for suppporting collision modes.
        */
        get: function () {
            return this.i.nk;
        },
        set: function (v) {
            this.i.nk = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "contentMemberPath", {
        /**
         * Gets or sets the content mapping property for the callouts.
        */
        get: function () {
            return this.i.oi;
        },
        set: function (v) {
            this.i.oi = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "targetSeries", {
        /**
         * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
        get: function () {
            if (this.i.my == null) {
                return null;
            }
            return this.i.my.externalObject;
        },
        set: function (v) {
            v == null ? this.i.my = null : this.i.my = v.i;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "isAutoCalloutBehaviorEnabled", {
        /**
         * Gets or sets how to select the final value to annotate.
        */
        get: function () {
            return this.i.nj;
        },
        set: function (v) {
            this.i.nj = ensureBool(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "calloutTextColor", {
        /**
         * Gets or sets the color to use for the callout text. Leave unset for an automatic value.
        */
        get: function () {
            return brushToString(this.i.pz);
        },
        set: function (v) {
            this.i.pz = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "calloutBackground", {
        /**
         * Gets or sets the brush that specifies how the backgrounds for the callouts of the layer are painted. Leave unset for an automatic value.
        */
        get: function () {
            return brushToString(this.i.pw);
        },
        set: function (v) {
            this.i.pw = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "calloutInterpolatedValuePrecision", {
        /**
         * Gets or sets the precision to use displaying values for interpolated crosshair positions.
        */
        get: function () {
            return this.i.n1;
        },
        set: function (v) {
            this.i.n1 = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "calloutOutline", {
        /**
         * Gets or sets the brush that specifies how the outlines for the callouts of the layer are painted.
        */
        get: function () {
            return brushToString(this.i.py);
        },
        set: function (v) {
            this.i.py = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "calloutLeaderBrush", {
        /**
         * Gets or sets the brush that specifies how the leader lines for the callouts of the layer are painted.
        */
        get: function () {
            return brushToString(this.i.px);
        },
        set: function (v) {
            this.i.px = stringToBrush(v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "calloutPaddingLeft", {
        /**
         * Gets or sets the left padding to use withing the callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: function () {
            return this.i.nu;
        },
        set: function (v) {
            this.i.nu = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "calloutPaddingTop", {
        /**
         * Gets or sets the top padding to use within the callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: function () {
            return this.i.nw;
        },
        set: function (v) {
            this.i.nw = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "calloutPaddingRight", {
        /**
         * Gets or sets the right padding to use within the callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: function () {
            return this.i.nv;
        },
        set: function (v) {
            this.i.nv = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "calloutPaddingBottom", {
        /**
         * Gets or sets the bottom padding to use within the callout. Leaving this NaN will use an automatic value related to the axis label margins.
        */
        get: function () {
            return this.i.nt;
        },
        set: function (v) {
            this.i.nt = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "calloutCollisionMode", {
        /**
         * Gets or sets the strategy to use for avoiding collisions between the callouts in this layer. Leave unset for an automatic value.
        */
        get: function () {
            return this.i.mt;
        },
        set: function (v) {
            this.i.mt = ensureEnum(CalloutCollisionMode_$type, v);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "calloutPositionPadding", {
        /**
         * Gets or sets the padding to add to the callout positioning. Leave unset for an automatic value.
        */
        get: function () {
            return this.i.nx;
        },
        set: function (v) {
            this.i.nx = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "calloutStrokeThickness", {
        /**
         * Gets or sets the stroke thickness for the callout backing. Leave unset for an automatic value.
        */
        get: function () {
            return this.i.ny;
        },
        set: function (v) {
            this.i.ny = +v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "textStyle", {
        /**
         * Gets or sets the stroke thickness for the axis annotation backing. Leave unset for an automatic value.
        */
        get: function () {
            return this.i.ot;
        },
        set: function (v) {
            this.i.ot = v;
        },
        enumerable: true,
        configurable: true
    });
    IgrCalloutLayer.prototype.invalidateCalloutContent = function () {
        this.i.o5();
    };
    Object.defineProperty(IgrCalloutLayer.prototype, "calloutContentUpdating", {
        get: function () {
            return this._calloutContentUpdating;
        },
        set: function (ev) {
            var _this = this;
            if (this._calloutContentUpdating !== null) {
                this.i.calloutContentUpdating = delegateRemove(this.i.calloutContentUpdating, this._calloutContentUpdating_wrapped);
                this._calloutContentUpdating_wrapped = null;
                this._calloutContentUpdating = null;
            }
            this._calloutContentUpdating = ev;
            this._calloutContentUpdating_wrapped = function (o, e) {
                var outerArgs = new CalloutContentUpdatingEventArgs();
                outerArgs._provideImplementation(e);
                _this._calloutContentUpdating(_this, outerArgs);
            };
            this.i.calloutContentUpdating = delegateCombine(this.i.calloutContentUpdating, this._calloutContentUpdating_wrapped);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "calloutLabelUpdating", {
        get: function () {
            return this._calloutLabelUpdating;
        },
        set: function (ev) {
            var _this = this;
            if (this._calloutLabelUpdating !== null) {
                this.i.calloutLabelUpdating = delegateRemove(this.i.calloutLabelUpdating, this._calloutLabelUpdating_wrapped);
                this._calloutLabelUpdating_wrapped = null;
                this._calloutLabelUpdating = null;
            }
            this._calloutLabelUpdating = ev;
            this._calloutLabelUpdating_wrapped = function (o, e) {
                var outerArgs = new CalloutLabelUpdatingEventArgs();
                outerArgs._provideImplementation(e);
                _this._calloutLabelUpdating(_this, outerArgs);
            };
            this.i.calloutLabelUpdating = delegateCombine(this.i.calloutLabelUpdating, this._calloutLabelUpdating_wrapped);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrCalloutLayer.prototype, "calloutSeriesSelecting", {
        get: function () {
            return this._calloutSeriesSelecting;
        },
        set: function (ev) {
            var _this = this;
            if (this._calloutSeriesSelecting !== null) {
                this.i.calloutSeriesSelecting = delegateRemove(this.i.calloutSeriesSelecting, this._calloutSeriesSelecting_wrapped);
                this._calloutSeriesSelecting_wrapped = null;
                this._calloutSeriesSelecting = null;
            }
            this._calloutSeriesSelecting = ev;
            this._calloutSeriesSelecting_wrapped = function (o, e) {
                var outerArgs = new CalloutSeriesSelectingEventArgs();
                outerArgs._provideImplementation(e);
                _this._calloutSeriesSelecting(_this, outerArgs);
            };
            this.i.calloutSeriesSelecting = delegateCombine(this.i.calloutSeriesSelecting, this._calloutSeriesSelecting_wrapped);
        },
        enumerable: true,
        configurable: true
    });
    return IgrCalloutLayer;
}(IgrAnnotationLayer));
export { IgrCalloutLayer };
